@@ -6,10 +6,12 @@ const _path = _interopRequireDefault(require('path'));
 
 module.exports = Ferdium => {
   const getMessages = () => {
-    const count = document.querySelectorAll('.unconsumed-badge').length;
-
-    // set Ferdium badge
-    Ferdium.setBadge(count);
+    let unread = 0;
+    const notificationBadge = document.querySelectorAll('.unreadcount')[0];
+    if (notificationBadge !== undefined) {
+      unread = Ferdium.safeParseInt(notificationBadge.textContent);
+    }
+    Ferdium.setBadge(unread);
   };
 
   Ferdium.loop(getMessages);
